# Generated by Django 3.2.9 on 2022-03-31 20:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='donationproject',
            name='name',
            field=models.CharField(max_length=50),
        ),
    ]
