{% extends "ddm/admin/forms/base_form.html" %}
{% load i18n admin_urls static admin_modify ddm_tags %}

{% block side_nav %}
  {% include 'ddm/admin/navigation/side_navigation/level_1_questionnaires.html' %}
  <div class="sq-nav-lvl-2">
    <div class="sq-nav-card-top sq-nav-card-active">Create New Questionnaire</div>
  </div>
{% endblock side_nav %}

{% block page_title %}
  Create New Questionnaire
{% endblock page_title %}
