# Generated by Django 3.2.9 on 2022-04-29 09:54

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0002_alter_donationproject_name'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='datadonation',
            name='time',
        ),
        migrations.AddField(
            model_name='datadonation',
            name='time_submitted',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AddField(
            model_name='donationproject',
            name='date_created',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AddField(
            model_name='donationproject',
            name='public_key',
            field=models.TextField(default=1234),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='donationproject',
            name='super_secret',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='datadonation',
            name='data',
            field=models.TextField(),
        ),
        migrations.AlterField(
            model_name='questionnaireresponse',
            name='data',
            field=models.TextField(),
        ),
        migrations.AlterField(
            model_name='questionnaireresponse',
            name='time_submitted',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
