{% extends "ddm/questionnaire/base_questionnaire.html" %}
{% load static %}

{% block title %}Umfrage nicht aktiv{% endblock %}

{% block content %}
  <div>
    <p>An dieser Befragung kann aktuell nicht teilgenommen werden.</p>
  </div>
{% endblock content %}
