{% extends "ddm/admin/forms/base_form.html" %}
{% load i18n admin_urls static admin_modify ddm_tags %}

{% block content %}
  <div>
    <p><b>Are you sure you want to delete "{{ object }}"? This step cannot be undone.</b></p>
  </div>
{% endblock %}

{% block form %}
  <form method="post">{% csrf_token %}
    <input type="submit" value="Yes, delete object" class="sq-btn sq-btn-warning">
  </form>
{% endblock %}
