# Generated by Django 3.2.13 on 2022-06-17 12:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0005_alter_donationproject_public_key'),
    ]

    operations = [
        migrations.AlterField(
            model_name='datadonation',
            name='data',
            field=models.BinaryField(),
        ),
        migrations.AlterField(
            model_name='questionnaireresponse',
            name='data',
            field=models.BinaryField(),
        ),
    ]
