{% extends 'ddm/project_admin/generic/page_with_form.html' %}

{% block page_title %}Delete Question{% endblock %}

{% block main_heading %}Delete Question "{{ object.name }}"{% endblock %}

{% block main_form %}
<form method='post'>
  {% csrf_token %}
  <p>You are about to delete the following question:</p>
  <div>
    <table>
      <tr>
        <td>Name:</td>
        <td>{{ object.name }}</td>
      </tr>
      <tr>
        <td>Blueprint:</td>
        <td>{{ object.blueprint }}</td>
      </tr>
      <tr>
        <td>Question Type:</td>
        <td>{{ object.question_type.label }}</td>
      </tr>
    </table>
  </div>
  <p>All collected data associated with this question will also be deleted. <b>This action cannot be reversed.</b></p>
  <p>Are you sure you want to delete this question?</p>
  <input class="btn-a btn-danger" type="submit" value="Delete question">
</form>
{% endblock %}

{% block breadcrumbs %}
Back to:
<a href="{% url 'project-list' %}">Projects</a> /
<a href="{% url 'project-detail' project_pk %}">Project Cockpit</a> /
<a href="{% url 'questionnaire-overview' project_pk %}">Questionnaire</a>
{% endblock %}
