{% extends "ddm/questionnaire/base_questionnaire.html" %}
{% load static %}

{% block title %}Umfrage beendet{% endblock %}

{% block content %}
  <div>
    <h1>Herzlichen Dank!</h1>
    <p>Vielen Dank für das Ausfüllen der Befragung. Sie sind am Ende angelangt und können das Fenster nun schliessen.</p>
  </div>
{% endblock content %}
