{% extends 'ddm/project_admin/generic/page_with_form.html' %}

{% block page_title %}Create {{ question_type }}{% endblock %}

{% block main_heading %}Create New {{ question_type }}{% endblock %}

{% block submit_label %}Create Question{% endblock %}

{% block breadcrumbs %}
Back to:
<a href="{% url 'project-list' %}">Projects</a> /
<a href="{% url 'project-detail' project_pk %}">Project Cockpit</a> /
<a href="{% url 'questionnaire-overview' project_pk %}">Questionnaire</a>
{% endblock %}
