{% extends "ddm/questionnaire/base_questionnaire.html" %}
{% load static %}

{% block title %}Umfrage beendet{% endblock %}

{% block content %}
  <div>
    <h1>Herzlichen Dank!</h1>
    <p>Sie haben an dieser Umfrage bereits teilgenommen.</p>
  </div>
{% endblock content %}
